package com.br.fechadura.mobile.ui.components

import androidx.compose.foundation.layout.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.AccountCircle
import androidx.compose.material.icons.filled.Search
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.ui.theme.FechaduraColor

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun TopAppBar(
    navController: NavController,
    showBackButton: Boolean = false,
    title: String = "",
    modifier: Modifier = Modifier,
    searchText: String,
    onSearchChange: (String) -> Unit
) {
    var isSearchActive by remember { mutableStateOf(false) }

    TopAppBar(
        title = {
            if (isSearchActive) {
                TextField(
                    value = searchText,
                    onValueChange = { newValue ->
                        onSearchChange(newValue)
                    },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(end = 8.dp),
                    leadingIcon = {
                        Icon(Icons.Default.Search, contentDescription = "Pesquisar")
                    },
                    label = { Text(text = "Pesquise aqui") },
                    placeholder = { Text("Quem procura?") },
                    singleLine = true,
                    colors = TextFieldDefaults.textFieldColors(
                        containerColor = Color.Transparent,
                        cursorColor = Color.Black, // Cor do cursor
                        focusedIndicatorColor = Color.Black, // Cor da linha quando o campo está focado
                        unfocusedIndicatorColor = Color.Black, // Cor da linha quando o campo não está focado
                        disabledIndicatorColor = Color.Black // Cor da linha quando o campo está desabilitado
                    )
                )
            } else {
                Text(title)
            }
        },
        colors = TopAppBarDefaults.topAppBarColors(
            containerColor = FechaduraColor
        ),
        navigationIcon = {
            if (showBackButton) {
                IconButton(onClick = {
                    if (isSearchActive) {
                        isSearchActive = false
                    } else {
                        navController.navigateUp()
                    }
                }) {
                    Icon(
                        imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                        contentDescription = "Voltar"
                    )
                }
            }
        },
        actions = {
            IconButton(onClick = { isSearchActive = !isSearchActive }) {
                Icon(Icons.Default.Search, contentDescription = "Abrir pesquisa")
            }
            IconButton(onClick = { navController.navigate("perfil") }) {
                Icon(Icons.Default.AccountCircle, contentDescription = "Meu perfil")
            }
        },
        modifier = modifier
    )
}

@Preview(showSystemUi = true)
@Composable
private fun TopAppBarPreview() {
    var searchText by remember { mutableStateOf("") }
    TopAppBar(
        navController = rememberNavController(),
        title = "Título da App Bar",
        searchText = searchText,
        onSearchChange = { searchText = it },
        showBackButton = true
    )
}