package com.br.fechadura.mobile.ui.screens.grupoPortas

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Switch
import androidx.compose.material3.SwitchDefaults
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import com.br.fechadura.mobile.api.model.GrupoPorta
import com.br.fechadura.mobile.ui.components.TopAppBar
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import com.br.fechadura.mobile.sampledata.sampleDataGroupDoors

@Composable
fun EditarGrupoPorta(
    navController: NavController,
    grupoPorta: GrupoPorta = sampleDataGroupDoors.first()
) {
    var nome by remember { mutableStateOf(grupoPorta.nome) }
    var descricao by remember { mutableStateOf(grupoPorta.descricao) }
    var ativo by remember { mutableStateOf(grupoPorta.ativo) }
    var portas by remember  { mutableStateOf(grupoPorta.portas) }
    var expanded by remember { mutableStateOf(false) }
    var selectedPortas by remember { mutableStateOf(portas.firstOrNull()?.ambiente ?: "Nenhuma porta disponível") }

    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Editar Grupo Porta",
                searchText = "",
                onSearchChange = {},
                showBackButton = true
            )
        },
        content = { paddingValues ->
            Box(
                modifier = Modifier
                    .fillMaxSize()
                    .background(Color.White)
                    .padding(paddingValues)
            ) {
                Column(
                    modifier = Modifier
                        .fillMaxSize()
                        .padding(24.dp),
                    verticalArrangement = Arrangement.Top,
                    horizontalAlignment = Alignment.Start
                ) {
                    OutlinedTextField(
                        value = nome,
                        onValueChange = { nome = it },
                        label = { Text("Nome") },
                        modifier = Modifier.fillMaxWidth()
                    )
                    OutlinedTextField(
                        value = descricao,
                        onValueChange = { descricao = it },
                        label = { Text("Descrição") },
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 16.dp)
                    )
                    Spacer(modifier = Modifier.height(16.dp))

                    Box(modifier = Modifier.fillMaxWidth()) {
                        OutlinedTextField(
                            value = selectedPortas,
                            onValueChange = {selectedPortas = it },
                            label = { Text("Ambiente") },
                            modifier = Modifier
                                .fillMaxWidth()
                                .clickable { expanded = true },
                            readOnly = false,
                            trailingIcon = {
                                Icon(Icons.Default.ArrowDropDown, contentDescription = null)
                            }
                        )
                        DropdownMenu(
                            expanded = expanded,
                            onDismissRequest = { expanded = false }, //true
                            modifier = Modifier.fillMaxWidth()
                        ) {
                            portas.forEach { portas ->
                                DropdownMenuItem(
                                    text = { Text(text = portas.ambiente) },
                                    onClick = {
                                        selectedPortas = portas.ambiente
                                        expanded = false //true
                                    }
                                )
                            }
                        }
                    }

                    Text(
                        text = "Ativo",
                        fontWeight = FontWeight.Bold,
                        modifier = Modifier
                            .padding(top = 16.dp))
                    Switch(
                        checked = ativo,
                        onCheckedChange = { ativo = it },
                        colors = SwitchDefaults.colors(
                            checkedTrackColor = Color(0xFF9FD19C),
                            uncheckedThumbColor = Color(0xFFB2D8B2),
                            uncheckedTrackColor = Color(0xFFD6E9D6),
                            disabledCheckedThumbColor = Color.Gray,
                            disabledUncheckedThumbColor = Color.Gray,
                            disabledCheckedTrackColor = Color.Gray,
                            disabledUncheckedTrackColor = Color.Gray
                        ),
                        thumbContent = if (ativo) {
                            {
                                Icon(
                                    imageVector = Icons.Filled.Check,
                                    contentDescription = null,
                                    modifier = Modifier.size(SwitchDefaults.IconSize),
                                )
                            }
                        } else {
                            null
                        }
                    )
                    Row(
                        modifier = Modifier.fillMaxWidth(),
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {

                        Button(
                            onClick = {
                                navController.popBackStack()
                            },
                            modifier = Modifier
                                .weight(1f)
                                .padding(start = 8.dp),
                            colors = ButtonDefaults.buttonColors(containerColor = Color(0xFF8AC28A))
                        ) {
                            Text(text = "Salvar")
                        }
                    }
                }
            }
        }
    )
}

