package com.br.fechadura.mobile.ui.screens.grupoPortas

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import androidx.compose.material3.Checkbox
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Switch
import androidx.compose.material3.SwitchDefaults
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.drawBehind
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.SolidColor
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.api.model.GrupoPorta
import com.br.fechadura.mobile.api.model.Porta
import com.br.fechadura.mobile.ui.components.TopAppBar
import com.br.fechadura.mobile.ui.theme.FechaduraMobileTheme

@Composable
fun VisualizarGrupoPorta(
    navController: NavController,
    grupoPorta: GrupoPorta = GrupoPorta(
        nome = "Salas de Informática",
        descricao = "Todas as portas de salas de Informática",
        ativo = true,
        portas = listOf(
            Porta("Porta A1", "Bloco A", true),
            Porta("Porta A2", "Bloco A", true),
            Porta("Porta A3", "Bloco A", true),
            Porta("Porta A4", "Bloco A", true),
            Porta("Porta A5", "Bloco A", true)
        )
    )
) {
    val expanded = remember { mutableStateOf(false) }
    val selectedPortas = remember { mutableStateOf(grupoPorta.portas.first().ambiente) }

    Scaffold(
        topBar = {
            TopAppBar(
                navController = navController,
                title = "Visualizar Grupo de Portas",
                searchText = "",
                onSearchChange = {},
                showBackButton = true
            )
        },
        content = { paddingValues ->
            Box(
                modifier = Modifier
                    .fillMaxSize()
                    .background(Color.White)
                    .padding(paddingValues)
            ) {
                Column(
                    modifier = Modifier
                        .fillMaxSize()
                        .padding(24.dp),
                    verticalArrangement = Arrangement.Top,
                    horizontalAlignment = Alignment.Start
                ) {

                    OutlinedTextField(
                        value = grupoPorta.nome,
                        onValueChange = {},
                        label = { Text("Nome") },
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 16.dp),
                        enabled = false
                    )

                    OutlinedTextField(
                        value = grupoPorta.descricao,
                        onValueChange = {},
                        label = { Text("Descrição") },
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 16.dp),
                        enabled = false
                    )

                    Box(modifier = Modifier.fillMaxWidth()) {
                        OutlinedTextField(
                            value = selectedPortas.value,
                            onValueChange = {},
                            label = { Text("Ambiente") },
                            modifier = Modifier
                                .fillMaxWidth()
                                .clickable { expanded.value = false },
                           enabled = false, //somente leitura
                            trailingIcon = {
                                Icon(Icons.Default.ArrowDropDown, contentDescription = null)
                            }
                        )
                        DropdownMenu(
                            expanded = expanded.value,
                            onDismissRequest = { expanded.value = false },
                            modifier = Modifier.fillMaxWidth()
                        ) {
                            grupoPorta.portas.forEach { porta ->
                                DropdownMenuItem(
                                    text = { Text(text = grupoPorta.nome) },
                                    onClick = {
                                        selectedPortas.value = grupoPorta.nome
                                        expanded.value = false
                                    }
                                )
                            }
                        }
                    }

                    Text(text = "Ativo:", fontWeight = FontWeight.Bold)
                    Switch(
                        checked = grupoPorta.ativo,
                        onCheckedChange = {},
                        enabled = false,
                        colors = SwitchDefaults.colors(
                            checkedTrackColor = Color(0xFF9FD19C),
                            uncheckedThumbColor = Color(0xFFB2D8B2),
                            uncheckedTrackColor = Color(0xFFD6E9D6),
                            disabledCheckedThumbColor = Color.Gray,
                            disabledUncheckedThumbColor = Color.Gray,
                            disabledCheckedTrackColor = Color.Gray,
                            disabledUncheckedTrackColor = Color.Gray
                        ),
                        thumbContent = if (grupoPorta.ativo) {
                            {
                                Icon(
                                    imageVector = Icons.Filled.Check,
                                    contentDescription = null,
                                    modifier = Modifier.size(SwitchDefaults.IconSize),
                                )
                            }
                        } else {
                            null
                        }
                    )
                }
            }
        }
    )
}



@Preview(showBackground = true)
@Composable
fun VisualizarGrupoPortaScreenPreview() {
    FechaduraMobileTheme {
        VisualizarGrupoPorta(navController = rememberNavController())
    }
}

